dnl Copyright (c) 2001-2001 Gerard Vermeulen <gvermeul@labs.polycnrs-gre.fr>

dnl X Window System, sets X_CFLAGS and X_LFLAGS
AC_DEFUN(AC_X_STUFF, [
	AC_MSG_RESULT(-- Configuring X Windows stuff --)
	dnl explicit X_LFLAGS
	AC_SUBST(X_LFLAGS)
	AC_PATH_XTRA
	X_LFLAGS="$X_LIBS $X_PRE_LIBS -lX11 $X_EXTRA_LIBS"
	dnl report
	AC_MSG_RESULT(-- Reporting X Windows stuff --)
	AC_MSG_RESULT(X Windows compiler flags: $X_CFLAGS)
	AC_MSG_RESULT(X Windows link flags:     $X_LFLAGS)
	AC_MSG_RESULT()
])

dnl Python, sets PYTHON, PYTHON_SITE, PYTHON_INCLUDE, NUMPY_INCLUDE, QT_VERSION
AC_DEFUN(AC_PYTHON_STUFF, [
	AC_MSG_RESULT(-- Configuring Python stuff --)
	dnl explicit PYTHON_SITE, PYTHON_INCLUDE, NUMPY_INCLUDE, QT_VERSION
	AC_SUBST(PYTHON_SITE)
	AC_SUBST(PYTHON_INCLUDE)
	AC_SUBST(NUMPY_INCLUDE)
	AC_SUBST(QT_VERSION)
	dnl find python interpreter
	programs="python2.1 python2.0 python1.6 python1.5 python"
	AC_PATH_PROGS(PYTHON, $programs, false)
	if test $PYTHON == "false"; then
		AC_MSG_ERROR(no PYTHON interpreter found)
	fi
	dnl find python version
	changequote(<<, >>)
	PY_VERSION=`$PYTHON -c 'import sys ; print sys.version[:3]'`
	changequote([, ])
	dnl find python prefix
	PY_PREFIX=`$PYTHON -c 'import sys ; print sys.prefix'`
	dnl find python exec_prefix
	PY_EXEC_PREFIX=`$PYTHON -c 'import sys ; print sys.exec_prefix'`
	PYTHON_SITE=$PY_PREFIX"/lib/python"$PY_VERSION/site-packages
	dnl check for PyQt by determining its Qt-version
	AC_MSG_CHECKING([for PyQt (by getting its Qt-version)])
	QT_VERSION=`$PYTHON -c 'import qt ; print qt.qVersion()'`
	AC_MSG_RESULT($QT_VERSION)
	if test "X$QT_VERSION" = "X"; then
		AC_MSG_ERROR(no PyQt found)
	fi 
	dnl find "Python.h"
	save_CPPFLAGS=$CPPFLAGS
	dir=$PY_PREFIX/include/python$PY_VERSION
	CPPFLAGS="$CPPFLAGS -I$dir"
	AC_MSG_CHECKING([for Python.h])
	AC_TRY_CPP([
			#include <Python.h>
		], [
			PYTHON_INCLUDE="-I$dir"
			AC_MSG_RESULT(yes)
		],
		AC_MSG_RESULT(no)
	)
	CPPFLAGS=$save_CPPFLAGS
	dnl find "arrayobject.h"
	dir="$dir/Numeric"
	CPPFLAGS="$CPPFLAGS -I$dir"
	AC_MSG_CHECKING([for arrayobject.h])
	AC_TRY_CPP([
			#include <arrayobject.h>
		], [
			NUMPY_INCLUDE="-I$dir"
			AC_MSG_RESULT(yes)
		],
		AC_MSG_RESULT(no)
	)
	CPPFLAGS=$save_CPPFLAGS
	dnl report
	AC_MSG_RESULT(-- Reporting Python stuff --)
	AC_MSG_RESULT(Python interpreter:        $PYTHON)
	AC_MSG_RESULT(Python site-packages:      $PYTHON_SITE)
	AC_MSG_RESULT(Python include flag:       $PYTHON_INCLUDE)
	AC_MSG_RESULT(NumPy include flag:        $NUMPY_INCLUDE)
	AC_MSG_RESULT(PyQt build for Qt-version: $QT_VERSION)
	AC_MSG_RESULT()
])

dnl sip, sets SIP, SIP_QT_SIP, SIP_INCLUDE, SIP_LFLAGS
dnl requires AC_PYTHON_STUFF 
AC_DEFUN(AC_SIP_STUFF, [
	AC_MSG_RESULT(-- Configuring sip stuff --)
	dnl explicit SIP_QT_SIP, SIP_INCLUDE
	AC_SUBST(SIP_VERSION)
	AC_SUBST(SIP_TIMELINE)
	AC_SUBST(SIP_QT_SIP)
	AC_SUBST(SIP_INCLUDE)
	AC_SUBST(SIP_LFLAGS)
	dnl external options
	AC_ARG_WITH(sip-include,
		[  --with-sip-include=DIR	sip.h is in DIR])
	AC_ARG_WITH(sip-library,
		[  --with-sip-library=DIR	sip library is in DIR])
	AC_ARG_WITH(sip-sources,
		[  --with-sip-sources=DIR	qt.sip is in DIR])
	dnl find sip
	AC_CHECK_PROGS(SIP, sip)
	dnl find sip version
	SIP_VERSION=`$SIP -V | sed -e "s|p.*||"`	
	dnl find timeline for sip FIXME
	SIP_TIMELINE=`$PYTHON timeline.py $SIP_VERSION`
	dnl look for qt.sip files
	sip_qt_sips="/usr/share/sip/qt /usr/local/share/sip/qt /usr/lib/sip /usr/local/lib/sip/qt"
	if test ! "X$with_sip_sources" = "X"; then
		sip_qt_sips="$with_sip_sources $sip_qt_sips"
	fi	
	for dir in $sip_qt_sips; do
		AC_CHECK_FILE($dir/qt.sip, [
			SIP_QT_SIP=$dir
			break]
		)
	done
	dnl find sip headers
	sip_includes="/usr/include/sip /usr/local/include/sip"
	if test ! "X$with_sip_include" = "X"; then
		sip_includes="$with_sip_include $sip_includes"
	fi	
	save_CPPFLAGS=$CPPFLAGS
	for dir in $sip_includes; do
		CPPFLAGS="$CPPFLAGS $PYTHON_INCLUDE -I$dir"
		AC_MSG_CHECKING([for sip.h in $dir])
		AC_TRY_CPP([
				#include <sip.h>
			], [
				SIP_INCLUDE="-I$dir"
				AC_MSG_RESULT(yes)
				break
			],
			AC_MSG_RESULT(no)
		)
		CPPFLAGS=$save_CPPFLAGS
	done
	CPPFLAGS=$save_CPPFLAGS
	dnl find sip libraries
	dnl FIXME: how to get all the python stuff for AC_TRY_LINK?
	if ! test "X$with_sip_library" = "X"; then
		SIP_LFLAG="-L$with_sip_library"
	fi
	dnl report
	AC_MSG_RESULT(-- Reporting sip stuff --)
	AC_MSG_RESULT(sip Simple Interface Program: $SIP)
	AC_MSG_RESULT(sip version:                  $SIP_VERSION)
	AC_MSG_RESULT(sip timeline:                 $SIP_TIMELINE)
	AC_MSG_RESULT(sip directory with qt.sip:    $SIP_QT_SIP)
	AC_MSG_RESULT(sip include flag:             $SIP_INCLUDE)
	AC_MSG_RESULT(sip link flag:                $SIP_LFLAG)
	AC_MSG_RESULT()
])

dnl AC_QT_STUFF, sets MOC, CXX_FLAGS, QT_INCLUDE, QT_LFLAGS
AC_DEFUN(AC_QT_STUFF, [
	AC_MSG_RESULT(-- Configuring Qt stuff --)
	dnl explicit QT_INCLUDE, QT_LFLAGS
	AC_SUBST(QT_INCLUDE)
	AC_SUBST(QT_LFLAGS)
	dnl external options
	AC_ARG_WITH(qt-root,
		[  --with-qt-root=DIR		qt files are in DIR/{bin,include,lib}])
	dnl we are looking for Qt >= 2.0
	qt_roots="/usr/lib/qt2 /usr/local/lib/qt2 /usr/qt2 /usr/local/qt2 /opt/qt2 /usr/lib/qt /usr/local/lib/qt /usr/qt /usr/local/qt /opt/qt"
	if test ! "X$with_qt_root" = "X"; then
		qt_roots="$with_qt_root $qt_roots"
	fi	
	dnl look for moc preprocessor in qt_roots
	for dir in $qt_roots; do
		qt_roots_PATH=$qt_roots_PATH$dir/bin:
	done
	AC_PATH_PROGS(MOC, moc2 moc, false, $qt_roots_PATH)
	dnl if not found look in PATH
	if test $MOC = "false"; then
		AC_PATH_PROGS(MOC, moc2 moc, false)
	fi
	dnl disable exceptions
	AC_MSG_CHECKING([for -fno-exceptions])
	AC_LANG_SAVE
	AC_LANG_CPLUSPLUS
	save_CXXFLAGS="$CXXFLAGS"
	CXXFLAGS="$CXXFLAGS -fno-exceptions"
	AC_TRY_COMPILE([],
		[
			int i;
		],
		AC_MSG_RESULT(yes),
		[
			CXXFLAGS="$save_CXXFLAGS"
			AC_MSG_RESULT(no)
		])
	AC_LANG_RESTORE
	dnl find the Qt headers
	save_CPPFLAGS=$CPPFLAGS
	found=false
	for dir in $qt_roots; do
		CPPFLAGS="$CPPFLAGS -I$dir/include"
		AC_MSG_CHECKING([for qobject.h in $dir/include])
		AC_TRY_CPP([
				#include <qobject.h>
			], [
				QT_INCLUDE="-I$dir/include"
				found=:
				AC_MSG_RESULT(yes)
				break
			],
			AC_MSG_RESULT(no)
		)
		CPPFLAGS=$save_CPPFLAGS
	done
	CPPFLAGS=$save_CPPFLAGS
	qt_includes="/usr/include/qt2 /usr/local/include/qt2 /usr/include/qt /usr/local/include/qt"
	if ! $found; then
		save_CPPFLAGS=$CPPFLAGS
		for dir in $qt_includes; do
			CPPFLAGS="$CPPFLAGS -I$dir"
			AC_MSG_CHECKING([for qobject.h in $dir])
			AC_TRY_CPP([
					#include <qobject.h>
				], [
					QT_INCLUDE="-I$dir"
				 	found=:
					AC_MSG_RESULT(yes)
				 	break
				],
				AC_MSG_RESULT(no)
			)
			CPPFLAGS=$save_CPPFLAGS
		done
	fi
	CPPFLAGS=$save_CPPFLAGS	
	dnl find the Qt libraries, look first in special directories 
	AC_LANG_SAVE
	AC_LANG_CPLUSPLUS
	save_CPPFLAG=$CPPFLAGS
	save_LDFLAGS=$LDFLAGS
	save_LIBS=$LIBS
	CPPFLAGS=$QT_INCLUDE
	LIBS="-lqt"  
	found=false
	for dir in $qt_roots; do
		LDFLAGS=-L$dir/lib		
		AC_MSG_CHECKING([for linking qt by $LDFLAGS $LIBS])
		AC_TRY_LINK([
				#include <qstring.h>
			], [
				QString version(QT_VERSION_STR);
			], [
				QT_LFLAGS=-L$dir/lib
				found=:
				AC_MSG_RESULT(yes)
				break
			],
			AC_MSG_RESULT(no)
		)
	done
	LDFLAGS=$save_LDFLAGS
	if ! $found; then
		AC_MSG_CHECKING([for linking qt by $LDFLAGS $LIBS])
		AC_TRY_LINK([
				#include <qstring.h>
			], [
				QString version(QT_VERSION_STR);
			], [
				found=:
				AC_MSG_RESULT(yes)
				break
			],
			AC_MSG_RESULT(no)
		)
	fi
	LIBS=$save_LIBS
	AC_LANG_RESTORE
	CPPFLAGS=$save_CPPFLAGS

	dnl report
	AC_MSG_RESULT(-- Reporting Qt stuff --)
	AC_MSG_RESULT(moc Meta Object Compiler: $MOC)
	AC_MSG_RESULT(Qt include flag:          $QT_INCLUDE)
	AC_MSG_RESULT(Qt link flag:             $QT_LFLAGS)
	AC_MSG_RESULT()
])

