#!/usr/bin/env python

# The Python version of qwt-0.3.0/examples/linux/cpuload/cpuload.cpp

import glob, os, sys

# The next statements assure importation of qwt and qwtc from the
# local source tree. This is useful for debugging and testing.
globs = glob.glob('../qwt/.libs/libqwtcmodule.*')
if globs:                               # found PyQwt modules made by libtool
    sys.path.insert(0, '../qwt')
    sys.path.insert(0, '../qwt/.libs')
globs = glob.glob('../build/lib.*/libqwtcmodule.*')
if globs:                               # found PyQwt modules made by distutils
    sys.path.insert(0, os.path.split(globs[0])[0])

from qt import *
from qwt import *

class LowPass:

    def __init__(self):
        self.tsampl = 1.0
        self.tconst = 0.0
        self.recalc()
        self.reset(0.0)

    def setTConst(self, t):
        self.tconst = t
        self.recalc()

    def setTSampl(self, t):
        self.tsampl = t
        self.recalc()

    def reset(self, v):
        self.val = v;
        
    def input(self, v):
        self.val = self.c2*v + self.c1*val

    def value(self):
        return self.val
    
    def recalc(self):
        if self.tconst > 0.00001:
            self.c1 = exp(-self.tsampl/self.tconst)
        else:
            self.c1 = 0.0
        self.c2 = 1.0 - self.c1


class ConfigDiag(QDialog):

    def __init__(self):
        pass

CpuUser = 0
CpuNice = 1
CpuSystem = 2
CpuIdle = 3
ThermoCnt = 4

class CPUloadDemo(QWidget):

    def __init__(self, app, *args):
        apply(QWidget.__init__, (self,) + args)

        puProg = QPopupMenu(self)
        puProg.insertItem("Quit", app.quit)

        puScale = QPopupMenu(self)
        puScale.insertItem("Dynamic", self.setDynScale)
        puScale.insertItem("Fixed (0-100)", self.setFixedScale)

        puConf = QPopupMenu(self)
        puConf.insertItem("Update Mode...", self.showDialog)
        puConf.insertItem("Scale", puScale)

        self.menu = QMenuBar(self)
        self.menu.insertItem("Program", puProg)                  
        self.menu.insertItem("Options", puConf);
    
        self.cfg = ConfigDiag

        self.lpFilters = []
        self.thermometers = []
        self.labels = []
        info = ["% User", "% Nice", "% System", " % Idle"]
        for i in range(ThermoCnt):
            self.lpFilters.append(LowPass().reset(0))
            self.thermometers.append(QwtThermo(
                self, setGeometry = (10 + i*60, 30, 50, 100),
                setOrientation = (QwtThermo.Vertical, QwtThermo.Left),
                setRange = (0.0, 100.0), setValue = 0.0, setBorderWidth = 1,
                setPipeWidth = 4, setFont = QFont("Helvetica", 10),
                setScaleMaxMajor = 6, setScaleMaxMinor = 5,
                setFillColor = QColor("MidnightBlue")))
            # a QLabel does not accept keyword arguments (yet)
            self.labels.append(QLabel(self, ""))
            self.labels[i].setText(info[i])
            self.labels[i].setGeometry(10 + i*60, 130, 50, 20)
            self.labels[i].setAlignment(Qt.AlignRight | Qt.AlignTop)

        self.setFixedSize(10+ThermoCnt*60, 150)

    def setTSampl(self, seconds):
        pass

    def setTConst(self, seconds):
        pass

    def setFixedScale(self):
        pass

    def setDynScale(self):
        pass

    def showDialog(self):
        pass


app = QApplication(sys.argv)
demo = CPUloadDemo(app)
app.setMainWidget(demo)
demo.setCaption("CPU Load")
demo.show()
app.exec_loop()
