#!/usr/bin/env python


import os, sys

# EDIT the Windows or Linux/Unix section to reflect your system:
# qt_dir -- must contain your Qt distribution (headers, binaries, libraries)
# sip_program -- must be the full path to the sip program
# sip_incdir -- must contain the files 'sip.h' and 'sipQt.h' 
# sip_spec_dirs -- must contain the files 'qt.sip' & friends
# library_dirs -- must contain 'libqtc' and 'sip.lib' on Windows
# library_dirs -- must contain shared library 'libqtcmodule.*' on Linux/Unix
#                 if libsip.so is not found, add its directory to library_dirs

if os.name == 'nt':
    # Windows-95, -98, NT?
    qt_dir = 'C:\qt'
    sip_program = 'C:\MyStuff\sip-2.5\sip\sip.exe'
    sip_incdir = 'C:\MyStuff\sip-2.5\siplib'
    sip_spec_dirs = ['C:\MyStuff\PyQt-2.5\sip']
    library_dirs = ['C:\MyStuff\PyQt-2.5\qt', 'C:\MyStuff\sip-2.5\siplib']
else:
    qt_dir = '/usr/lib/qt2'
    sip_program = '/usr/bin/sip'
    sip_incdir = '/usr/include/sip'
    sip_spec_dirs = ['/usr/share/sip/qt']
    library_dirs = ['/usr/lib/python2.1/site-packages']

# IF YOU NEED TO EDIT BELOW THIS LINE -- IT IS A BUG

if os.name == 'nt': 
    libraries = ['libqtc']
else:
    libraries = ['qtcmodule']

file = open('setup.cfg', 'w')
file.write('[build_ext]\n')
file.write('qt_dir=%s\n' % qt_dir)
file.write('sip_program=%s\n' % sip_program)
file.write('sip_incdir=%s\n' % sip_incdir)
file.close()

# os.popen should work on Unix AND Windows for python >= 2.0
if not hasattr(sys, 'version_info') or sys.version_info < (2,0,0,'alpha',0):
    raise SystemExit, 'Python-2.0 or later required to build PyQwt.'

from glob import glob
import post_sip
from distutils.core import setup
from distutils.file_util import copy_file
from pyqt_support import PyQtExtension, build_ext_pyqt, install_data_pyqt

data_files = []
if os.name == 'nt':
    for filename in ['examples/BodeDemo.py',
                     'examples/CurveDemo1.py',
                     'examples/CurveDemo2.py',
                     'examples/DataDemo.py',
                     'examples/ListArrayDemo.py',
                     'examples/MinPackDemo.py',
                     'examples/RadioDemo.py',
                     'examples/SimpleDemo.py',
                     'examples/SliderDemo.py']:
        copy_file(filename, filename+'w')
    data_files.append(('examples',
                       ['examples/README'] + glob('examples/*.pyw')))
else:
    data_files.append(('examples',
                       ['examples/README'] + glob('examples/*.py')))

data_files.append(('pyuic', ['pyuic/LegendBaseDialog.py',
                             'pyuic/LegendBaseDialog.ui',
                             'pyuic/LegendDialog.py',
                             'pyuic/QwtCounter.cw',
                             'pyuic/QwtCounter.xpm',
                             'pyuic/QwtPlot.cw',
                             'pyuic/QwtPlot.xpm',
                             'pyuic/README']))

data_files.append(('doc', glob('doc/PyQwt/*.html')))

pyQwt = PyQtExtension('qwt', glob('sources/*.cpp') + ['qwt/qwt_numeric.cpp'],
                      sip_spec_dirs = sip_spec_dirs,
                      sip_fix = post_sip.fix,
                      moc_headers = ['include/qwt_counter.h',
                                     'include/qwt_legend.h',
                                     'include/qwt_pixframe.h',
                                     'include/qwt_plot.h',
                                     'include/qwt_sldbase.h',
                                     'include/qwt_thermo.h'],
                      include_dirs = ['include'],
                      library_dirs = library_dirs,
                      libraries = libraries)


setup(name              = "PyQwt",
      version           = "0.29.94",
      licence           = "LGPL",
      url               = "http://gerard.vermeulen.free.fr",
      author            = "Gerard Vermeulen",
      author_email      = "gvermeul@labs.polycnrs-gre.fr",
      description       = "Python bindings for the Qwt library",
      long_description  = "Python bindings for the Qwt library",
      cmdclass          = {'build_ext': build_ext_pyqt,
                           'install_data': install_data_pyqt},
      extra_path        = 'PyQwt',
      ext_modules       = [pyQwt],
      data_files        = data_files)
