/*-*- c++ -*-******************************************************************
 * Qwt Widget Library 
 * Copyright (C) 1997   Josef Wilgen
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *****************************************************************************/

#include "../include/qwt_clrfltr.h"
#include "../include/qwt_math.h"


QwtColorFilter NoColorFilter;

/*!
  \brief Filter function which changes a color to grayscale
  \param c color to be modified
*/
QColor QwtFltrGray::operator()(const QColor &c) const
{
    int g = qGray(c.rgb());
    if (d_inv)
       g = 255 - g;
    return QColor(g, g, g);
}


/*!
  \brief ctor

  QwtFltrDim uses QColor::dark() (See Qt Manual)
  \param factor Darkening factor. A factor greater than 100 produces a darker
  color, a factor smaller than 100 produces a brighter color.
*/
QwtFltrDim::QwtFltrDim(int factor)
{
    d_dim = qwtLim(factor, 1, 10000);
}

/*!
  \brief Filter function

  Darkens or brightens a specified color.
  The behaviour of the filter is influenced by the
  constructor argument.
  \todo Parameter documentation
  \sa QwtFltrDim::QwtFltrDim()
*/
QColor QwtFltrDim::operator()(const QColor &c) const
{
    return QColor(c.dark(dimFactor()));
}


/*!
  \brief Filter function

  Inverts the RGB values of a specified color.
  \param c Color to be modified
*/
QColor QwtFltrInv::operator()(const QColor &c) const
{
    int r, g, b;
    c.rgb(&r, &g, &b);
    return QColor(255-r, 255-g, 255-b);
}







